# eric7.PipInterface.PipFreezeDialog

Module implementing a dialog to generate a requirements file.

### Global Attributes

None

### Classes

PipFreezeDialog | Class implementing a dialog to generate a requirements file.
PipFreezeDialogModes | Class defining the various dialog modes.

### Functions

None

## PipFreezeDialog

Class implementing a dialog to generate a requirements file.

### Derived from

QDialog, Ui_PipFreezeDialog

### Class Attributes

None

### Class Methods

None

### Methods

PipFreezeDialog | Constructor
__refresh | Private slot to refresh the displayed list.
__updateButtons | Private method to set the state of the various buttons.
__writeToFile | Private method to write the requirements text to a file.
closeEvent | Protected slot implementing a close event handler.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_copyButton_clicked | Private slot to copy the requirements text to the clipboard.
on_insertButton_clicked | Private slot to insert the requirements text at the cursor position of the current editor.
on_localCheckBox_clicked | Private slot handling the switching of the local mode.
on_replaceAllButton_clicked | Private slot to replace the text of the current editor with the requirements text.
on_replaceSelectionButton_clicked | Private slot to replace the selected text of the current editor with the requirements text.
on_requirementsEdit_textChanged | Private slot handling changes of the requirements text.
on_requirementsFilePicker_textChanged | Private slot handling a change of the requirements file name.
on_saveButton_clicked | Private slot to save the requirements text to the requirements file.
on_saveToButton_clicked | Private slot to write the requirements text to a new file.
on_userCheckBox_clicked | Private slot handling the switching of the user-site mode.
start | Public method to start the command.

### Static Methods

None

#### PipFreezeDialog (Constructor)

PipFreezeDialog(pip, mode=PipFreezeDialogModes.Requirements, parent=None)

Constructor

pip (Pip)
  reference to the master object
mode (PipFreezeDialogModes (optional))
  dialog mod (defaults to PipFreezeDialogModes.Requirements)
parent (QWidget (optional))
  reference to the parent widget (defaults to None

#### PipFreezeDialog.__refresh

__refresh()

Private slot to refresh the displayed list.

#### PipFreezeDialog.__updateButtons

__updateButtons()

Private method to set the state of the various buttons.

#### PipFreezeDialog.__writeToFile

__writeToFile(fileName)

Private method to write the requirements text to a file.

fileName (str)
  name of the file to write to

#### PipFreezeDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e (QCloseEvent)
  close event

#### PipFreezeDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### PipFreezeDialog.on_copyButton_clicked

on_copyButton_clicked()

Private slot to copy the requirements text to the clipboard.

#### PipFreezeDialog.on_insertButton_clicked

on_insertButton_clicked()

Private slot to insert the requirements text at the cursor position of the current editor.

#### PipFreezeDialog.on_localCheckBox_clicked

on_localCheckBox_clicked()

Private slot handling the switching of the local mode.

#### PipFreezeDialog.on_replaceAllButton_clicked

on_replaceAllButton_clicked()

Private slot to replace the text of the current editor with the requirements text.

#### PipFreezeDialog.on_replaceSelectionButton_clicked

on_replaceSelectionButton_clicked()

Private slot to replace the selected text of the current editor with the requirements text.

#### PipFreezeDialog.on_requirementsEdit_textChanged

on_requirementsEdit_textChanged()

Private slot handling changes of the requirements text.

#### PipFreezeDialog.on_requirementsFilePicker_textChanged

on_requirementsFilePicker_textChanged(txt)

Private slot handling a change of the requirements file name.

txt (str)
  name of the requirements file

#### PipFreezeDialog.on_saveButton_clicked

on_saveButton_clicked()

Private slot to save the requirements text to the requirements file.

#### PipFreezeDialog.on_saveToButton_clicked

on_saveToButton_clicked()

Private slot to write the requirements text to a new file.

#### PipFreezeDialog.on_userCheckBox_clicked

on_userCheckBox_clicked()

Private slot handling the switching of the user-site mode.

#### PipFreezeDialog.start

start(venvName)

Public method to start the command.

venvName (str)
  name of the environment to act upon

Up

## PipFreezeDialogModes

Class defining the various dialog modes.

### Derived from

enum.Enum

### Class Attributes

Constraints
Requirements

### Class Methods

None

### Methods

None

### Static Methods

None

Up